@@ -54,6 +54,7 @@
     #include <X11/extensions/Xdamage.h>
     #include <X11/extensions/Xrender.h>
     #include <location/location-gps-device.h>
+    #include <location/location-gpsd-control.h>
 #else
     #include <hildon-widgets/hildon-banner.h>
 #endif
@@ -245,6 +246,7 @@ typedef struct applet_config{
     gboolean	downloading_after_connecting;
     gboolean    gps_station;
     gboolean	show_wind;
+    gboolean	show_wind_gust;
     GdkColor	font_color;
     GdkColor	background_color;
 }AppletConfig;
@@ -314,7 +316,11 @@ typedef struct OMWeatherApplet{
     GSList		*tab_of_window_popup;
 #ifdef OS2008
     guint		gps_id_connection;
-    LocationGPSDevice 	*gps_device;
+    guint		gps_id_gpsdevice;
+    guint		gps_run;
+    guint		gps_stop;
+    LocationGPSDevice   *gps_device;
+    LocationGPSDControl *gps_control;
     Station		gps_station;
     gdouble		temporary_station_latitude;
     gdouble		temporary_station_longtitude;
