@@ -541,6 +541,16 @@ read_config(AppletConfig *config){
     else
         config->show_wind = FALSE;
 
+    /* Get Show wind gust Button State. Default is FALSE */
+    value = gconf_client_get(gconf_client, GCONF_KEY_SHOW_WIND_GUST, NULL);
+    if(value){
+        config->show_wind_gust = gconf_value_get_bool(value);
+        gconf_value_free(value);
+    }
+    else
+        config->show_wind_gust = TRUE;
+
+
     /* Get Show Station Name. Default is TRUE */
     value = gconf_client_get(gconf_client, GCONF_KEY_SHOW_STATION_NAME, NULL);
     if(value){
@@ -831,7 +841,11 @@ config_save(AppletConfig *config){
      /* Save Show Wind Button State */
     gconf_client_set_bool(gconf_client,
         		GCONF_KEY_SHOW_WIND,
-			config->show_wind, NULL);	    
+			config->show_wind, NULL);
+     /* Save Show Wind gust Button State */
+    gconf_client_set_bool(gconf_client,
+        		GCONF_KEY_SHOW_WIND_GUST,
+			config->show_wind_gust, NULL);
      /* Show Station Name */
     gconf_client_set_bool(gconf_client,
         		GCONF_KEY_SHOW_STATION_NAME,
