@@ -131,11 +131,9 @@ gboolean timer_handler(gpointer data){
 */                    
                     if (calculate_distance(app->gps_station.latitude,app->gps_station.longtitude,
                                            app->temporary_station_latitude,app->temporary_station_longtitude)>10){
-								   
                         get_nearest_station(app->temporary_station_latitude,app->temporary_station_longtitude,
             		                    &app->gps_station);		    
 			if ((strlen(app->gps_station.id0) > 0) && (strlen(app->gps_station.name) > 0)){
-		    
 			    app->gps_station.latitude = app->temporary_station_latitude;
 			    app->gps_station.longtitude = app->temporary_station_longtitude;
 			    delete_all_gps_stations();
@@ -145,7 +143,7 @@ gboolean timer_handler(gpointer data){
 				app->config->current_station_id = g_strdup(app->gps_station.id0);		
 			    }
 			    config_save(app->config);
-		    	    update_weather(TRUE);
+		    	    update_weather(FALSE);
 			    redraw_home_window(FALSE);
 			}        
                     }
