@@ -339,7 +339,7 @@ gboolean weather_window_popup(GtkWidget *widget, GdkEvent *event,
 
 /* Day tabs */
     tmp = app->wsd.days;
-    while(tmp && i < app->config->days_to_show + k){
+    while(tmp && i < Max_count_weather_day){
 	day = (GSList*)tmp->data;
 
 	/* Acceleration of starting gtk_notebook */
