@@ -47,8 +47,7 @@ extern gboolean		not_event;
 extern gchar		path_large_icon[_POSIX_PATH_MAX];
 extern WeatherSource	weather_sources[];
 /*******************************************************************************/
-void weather_window_settings(GtkWidget *widget, GdkEvent *event,
-				gpointer user_data);
+void weather_window_settings(GtkWidget *widget, gpointer user_data);
 void station_list_view_select_handler(GtkTreeView *tree_view,
 			    gpointer user_data);
 gboolean process_locations_tab(GtkWidget *vbox);
